You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@ignite.apache.org by dp...@apache.org on 2018/11/03 20:30:19 UTC

ignite git commit: IGNITE-8896 fix for wrong javadoc for TcpCommunicationSpi.setSlowClientQueueLimit(). - Fixes #5225.

Repository: ignite
Updated Branches:
  refs/heads/master 709612489 -> 4348915d6


IGNITE-8896 fix for wrong javadoc for TcpCommunicationSpi.setSlowClientQueueLimit(). - Fixes #5225.

Signed-off-by: Dmitriy Pavlov <dp...@apache.org>


Project: http://git-wip-us.apache.org/repos/asf/ignite/repo
Commit: http://git-wip-us.apache.org/repos/asf/ignite/commit/4348915d
Tree: http://git-wip-us.apache.org/repos/asf/ignite/tree/4348915d
Diff: http://git-wip-us.apache.org/repos/asf/ignite/diff/4348915d

Branch: refs/heads/master
Commit: 4348915d63a2a8d807017542c593b2a63ab139ea
Parents: 7096124
Author: Rodion4ik <ro...@mail.ru>
Authored: Sat Nov 3 23:29:16 2018 +0300
Committer: Dmitriy Pavlov <dp...@apache.org>
Committed: Sat Nov 3 23:29:16 2018 +0300

----------------------------------------------------------------------
 .../ignite/spi/communication/tcp/TcpCommunicationSpi.java      | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/ignite/blob/4348915d/modules/core/src/main/java/org/apache/ignite/spi/communication/tcp/TcpCommunicationSpi.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/spi/communication/tcp/TcpCommunicationSpi.java b/modules/core/src/main/java/org/apache/ignite/spi/communication/tcp/TcpCommunicationSpi.java
index 33b1384..427db08 100755
--- a/modules/core/src/main/java/org/apache/ignite/spi/communication/tcp/TcpCommunicationSpi.java
+++ b/modules/core/src/main/java/org/apache/ignite/spi/communication/tcp/TcpCommunicationSpi.java
@@ -1843,7 +1843,7 @@ public class TcpCommunicationSpi extends IgniteSpiAdapter implements Communicati
      * When set to a positive number, communication SPI will monitor clients outbound message queue sizes and will drop
      * those clients whose queue exceeded this limit.
      * <p/>
      * Usually this value should be set to the same value as {@link #getMessageQueueLimit()} which controls
      * message back-pressure for server nodes. The default value for this parameter is {@code 0}
      * which means {@code unlimited}.
      *
@@ -2207,8 +2207,8 @@ public class TcpCommunicationSpi extends IgniteSpiAdapter implements Communicati
                 "since may produce significant delays with some scenarios.");
 
         if (slowClientQueueLimit > 0 && msgQueueLimit > 0 && slowClientQueueLimit >= msgQueueLimit) {
-            U.quietAndWarn(log, "Slow client queue limit is set to a value greater than message queue limit " +
-                "(slow client queue limit will have no effect) [msgQueueLimit=" + msgQueueLimit +
+            U.quietAndWarn(log, "Slow client queue limit is set to a value greater than or equal to message " +
+                "queue limit (slow client queue limit will have no effect) [msgQueueLimit=" + msgQueueLimit +
                 ", slowClientQueueLimit=" + slowClientQueueLimit + ']');
         }
@@ -1843,7 +1843,7 @@ public class TcpCommunicationSpi extends IgniteSpiAdapter implements Communicati
      * those clients whose queue exceeded this limit.
      * <p/>
-     * Usually this value should be set to the same value as {@link #getMessageQueueLimit()} which controls
+     * This value should be set to less or equal value than {@link #getMessageQueueLimit()} which controls
      * message back-pressure for server nodes. The default value for this parameter is {@code 0}
      * which means {@code unlimited}.